@@ -88,6 +88,7 @@ class Inst:
     def merge(self, fn, other):
         fn = _fn2gen(fn)
 
+        empty = object()
         def _step(krs1, krs2):
             try:
                 k1, rs1 = next(krs1)
@@ -95,22 +96,22 @@ class Inst:
                 while True:
                     if k1 == k2:
                         yield from fn(list(rs1), list(rs2))
-                        k1 = k2 = None
+                        k1 = k2 = empty 
                         k1, rs1 = next(krs1)
                         k2, rs2 = next(krs2)
                     elif k1 < k2:
                         yield from fn(list(rs1), [])
-                        k1 = None
+                        k1 = empty 
                         k1, rs1 = next(krs1)
                     else:
                         yield from fn([], list(rs2))
-                        k2 = None
+                        k2 = empty 
                         k2, rs2 = next(krs2)
             except StopIteration:
                 # unconsumed
-                if k1:
+                if k1 is not empty:
                     yield from fn(list(rs1), [])
-                if k2:
+                if k2 is not empty:
                     yield from fn([], list(rs2))
 
                 for _, rs1 in krs1:
