@@ -91,10 +91,10 @@ class TestGeneral(unittest.TestCase):
             {'col1': 'e', 'col2': None, 'col3': 4}]
         )
 
-    # def test_concat(self):
-    #     conn = Conn(self.dbfile)
-    #     conn['t1'] = Inst(table1)
-    #     conn['t1_double'] = Inst(table1).concat(conn.inst('t1'))
-    #     self.assertEqual(conn['t1'] + conn['t1'], conn['t1_double'])
+    def test_concat(self):
+        conn = Conn(self.dbfile)
+        conn['t1'] = Inst(table1)
+        conn['t1_double'] = Inst(table1).concat(conn.inst('t1'))
+        self.assertEqual(conn['t1'] + conn['t1'], conn['t1_double'])
     
         
